#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hoauth2
version:              2.14.0
visibility:           public
id:                   hoauth2-2.14.0-C3YCvHOFLnQIfcZJoc9oVI
key:                  hoauth2-2.14.0-C3YCvHOFLnQIfcZJoc9oVI
license:              MIT
copyright:            Haisheng Wu
maintainer:           Haisheng Wu <freizl@gmail.com>
author:               Haisheng Wu
stability:            Beta
homepage:             https://github.com/freizl/hoauth2
synopsis:             Haskell OAuth2 authentication client
description:
    This is Haskell binding of OAuth2 Authorization framework and Bearer Token Usage framework.

category:             Network
abi:                  ed8095478fd54d226747e7ccf1351c8a
exposed:              True
exposed-modules:
    Network.OAuth.OAuth2 Network.OAuth.OAuth2.AuthorizationRequest
    Network.OAuth.OAuth2.HttpClient Network.OAuth.OAuth2.TokenRequest
    Network.OAuth2.Experiment
    Network.OAuth2.Experiment.Flows.AuthorizationRequest
    Network.OAuth2.Experiment.Flows.DeviceAuthorizationRequest
    Network.OAuth2.Experiment.Flows.RefreshTokenRequest
    Network.OAuth2.Experiment.Flows.TokenRequest
    Network.OAuth2.Experiment.Flows.UserInfoRequest
    Network.OAuth2.Experiment.Grants.AuthorizationCode
    Network.OAuth2.Experiment.Grants.ClientCredentials
    Network.OAuth2.Experiment.Grants.DeviceAuthorization
    Network.OAuth2.Experiment.Grants.JwtBearer
    Network.OAuth2.Experiment.Grants.ResourceOwnerPassword
    Network.OAuth2.Experiment.Pkce Network.OAuth2.Experiment.Types

hidden-modules:
    Network.HTTP.Client.Contrib Network.OAuth.OAuth2.Internal
    Network.OAuth2.Experiment.Grants Network.OAuth2.Experiment.Utils
    Paths_hoauth2

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hoauth2-2.14.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hoauth2
hs-libraries:         HShoauth2-2.14.0-C3YCvHOFLnQIfcZJoc9oVI
depends:
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V base-4.18.2.1
    base64-1.0-EtI0emSHewY4KdiH7R5JvV binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.5-7t0kyZzS7otBofbnZ6zHEy
    data-default-0.7.1.3-6zOkPXxynjr15x05rRaNvG exceptions-0.10.7
    http-conduit-2.3.9.1-KDnV8VsG74SBT5pJfJbgZK
    http-types-0.12.4-2JHh5Qo0ssgCXdBZ0yuSfo
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3 text-2.0.2
    transformers-0.6.1.0 uri-bytestring-0.3.3.1-6tTjyarEottE4mZ6OoWOPR
    uri-bytestring-aeson-0.1.0.9-ClUmy4iFDmg5zBjvrC1D9m

haddock-interfaces:   /usr/share/doc/haskell-hoauth2/html/hoauth2.haddock
haddock-html:         /usr/share/doc/haskell-hoauth2/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

